@@ -36,16 +36,24 @@ from timething import dataset, job, text, utils  # type: ignore
     type=int,
     help="Number of worker processes to use",
 )
+@click.option(
+    "--use-gpu",
+    type=bool,
+    default=True,
+    show_default=True,
+    help="Use the gpu, if we have one",
+)
 def main(
     model: str,
     metadata: str,
     alignments_dir: str,
     batch_size: int,
     n_workers: int,
+    use_gpu: bool,
 ):
     """Timething is a library for aligning text transcripts with audio.
 
-    You provide a audio files, as well as a text file with the complete text
+    You provide the audio files, as well as a text file with the complete text
     transcripts. Timething will output a list of time-codes for each word and
     character that indicate when this word or letter was spoken in the audio
     you provided.
@@ -65,6 +73,7 @@ def main(
         Path(alignments_dir),
         batch_size=batch_size,
         n_workers=n_workers,
+        gpu=use_gpu,
     )
 
     # construct the generic model text cleaner
@@ -73,3 +82,7 @@ def main(
     # go
     print("starting aligment job...")
     j.run()
+
+
+if __name__ == "__main__":
+    main()
